@@ -62,7 +62,7 @@ def calculate_y(expr01, x, y, terminals, add_coef=True, x_test=None, y_test=None
             assert y.shape == pre_y.shape
             pre_y = check_array(pre_y, ensure_2d=False)
 
-    except (DataConversionWarning, AssertionError, ValueError, AttributeError, KeyError, ZeroDivisionError):
+    except (DataConversionWarning, TypeError,AssertionError, ValueError, AttributeError, KeyError, ZeroDivisionError):
         pre_y = None
 
     return pre_y, expr01
@@ -440,6 +440,8 @@ def score_dim(dim_, dim_type, fuzzy=False):
             return 1 if dim_.isinteger() else 0
         elif dim_type == 'coef':
             return 1 if not dim_.anyisnan() else 0
+        elif dim_type == 'ignore':
+            return 1
         else:
             raise TypeError("dim_type should be None,'coef', 'integer', special Dim or list of Dim")
     elif isinstance(dim_type, list):
@@ -532,6 +534,13 @@ def calculate_collect_(ind, context, x, y, terminals_and_constants_repr, gro_ter
                        details=False):
     expr01 = compile_context(ind, context, gro_ter_con)
 
+    if cal_dim:
+        dim, dim_score = calcualte_dim_score(expr01, terminals_and_constants_repr,
+                                             dim_ter_con_list, dim_type, fuzzy,
+                                             dim_maps=dim_maps)
+    else:
+        dim, dim_score = dless, 1
+
     score, expr01, pre_y = calculate_cv_score(expr01, x, y, terminals_and_constants_repr,
                                               cv=cv, refit=refit,
                                               add_coef=add_coef, inter_add=inter_add,
@@ -543,13 +552,6 @@ def calculate_collect_(ind, context, x, y, terminals_and_constants_repr, gro_ter
                                               details=details
                                               )
 
-    if cal_dim:
-        dim, dim_score = calcualte_dim_score(expr01, terminals_and_constants_repr,
-                                             dim_ter_con_list, dim_type, fuzzy,
-                                             dim_maps=dim_maps)
-    else:
-        dim, dim_score = dless, 1
-
     return score, dim, dim_score, expr01, pre_y
 
 
